@@ -153,7 +153,10 @@ int tree_walker(char **trees) {
 
 #elif HAVE_NFTW
 
-/* #define _XOPEN_SOURCE 500 */
+#if defined(__digital__) && defined(__unix__)
+/* Shut up tru64's cc(1) */
+#define _XOPEN_SOURCE_EXTENDED
+#endif
 #include <ftw.h>
 
 int ftw_process_path(const char *opath, const struct stat *statbuf, int flag,
